@@ -4,7 +4,7 @@
 # User-space: http://www.csis.gvsu.edu/~abreschm/uafhs/
 
 # These are the only variables that need to be changed:
-opera_version=9.51
+opera_version=9.52
 debug_level='0'			# From 0 to 2
 
 # Everything else should look after itself:
@@ -95,7 +95,7 @@ guess_os()
     # other ideas are $OSTYPE, arch
     # Return = $os
 
-    os=`uname -s` || error 'uname'
+    os=`uname -s` || error uname
     case $os in
 	FreeBSD|NetBSD|DragonFly) os=AnyBSD;;
 	SunOS*) os=SunOS;;
@@ -265,7 +265,7 @@ case $1 in
 	then
 	    flag_mode='--interactive'
 	    shift
-	else error 'conflict'
+	else error conflict
 	fi
 	;;
 
@@ -275,7 +275,7 @@ case $1 in
 	then
 	    flag_mode='--standard'
 	    shift
-	else error 'conflict'
+	else error conflict
 	fi
 	;;
 
@@ -285,7 +285,7 @@ case $1 in
 	    flag_mode='--force'
 	    shift
 	    if test -z "$1"
-	    then error 'missing'
+	    then error missing
 	    elif test -z "$2"
 	    then
 		str_paramprefix=`echo "$1" | sed -e 's/--prefix=//'`
@@ -293,11 +293,11 @@ case $1 in
 		warn 'Do you want to continue [y/n]?'
 		read continue
 		if test "${continue}" != 'y' && test "${continue}" != 'Y'
-		then error 'abort'
+		then error abort
 		else shift
 		fi
 	    elif test -z "$6"
-	    then error 'missing'
+	    then error missing
 	    else
 		str_paramexec="$1"
 		str_paramwrapper="$2"
@@ -307,7 +307,7 @@ case $1 in
 		str_paramman="$6"
 		shift 6
 	    fi
-	else error 'conflict'
+	else error conflict
 	fi
 	;;
 
@@ -332,7 +332,7 @@ case $1 in
 		then
 		    flag_mode='--prefix='
 		    str_paramprefix="${param}"
-		else error 'conflict'
+		else error conflict
 		fi
 	    fi
 	    ;;
@@ -346,7 +346,7 @@ case $1 in
 		then
 		    flag_mode='--prefix='
 		    str_paramexec="${param}"
-		else error 'conflict'
+		else error conflict
 		fi
 	    fi
 	    ;;
@@ -360,7 +360,7 @@ case $1 in
 		then
 		    flag_mode='--prefix='
 		    str_paramwrapper="${param}"
-		else error 'conflict'
+		else error conflict
 		fi
 	    fi
 	    ;;
@@ -374,7 +374,7 @@ case $1 in
 		then
 		    flag_mode='--prefix='
 		    str_paramman="${param}"
-		else error 'conflict'
+		else error conflict
 		fi
 	    fi
 	    ;;
@@ -388,7 +388,7 @@ case $1 in
 		then
 		    flag_mode='--prefix='
 		    str_paramdoc="${param}"
-		else error 'conflict'
+		else error conflict
 		fi
 	    fi
 	    ;;
@@ -402,7 +402,7 @@ case $1 in
 		then
 		    flag_mode='--prefix='
 		    str_paramshare="${param}"
-		else error 'conflict'
+		else error conflict
 		fi
 	    fi
 	    ;;
@@ -416,12 +416,12 @@ case $1 in
 		then
 		    flag_mode='--prefix='
 		    str_paramplugin="${param}"
-		else error 'conflict'
+		else error conflict
 		fi
 	    fi
 	    ;;
 
-     *) error 'invalid';;
+     *) error invalid;;
 esac
 done
     debug_msg 1 "flag_mode = $flag_mode"
@@ -482,7 +482,7 @@ set_os_spesific()
 		fi
 	;;
 
-	*) error 'os';;
+	*) error os;;
     esac
     debug_msg 1 "cpf = $cpf"
     debug_msg 1 "cpv = $cpv"
@@ -530,7 +530,7 @@ con_firm()
 
 	    [aAcCqQ]|[aA][bB][oO][rR][tT]|[cC][aA][nN][cC][eE][lL]|[qQ][uU][iI][tT])
 		if test "$2"
-		then error "abort"
+		then error abort
 		else warn 'Invalid answer, try again:'
 		fi
 		;;
@@ -830,7 +830,7 @@ generate_wrapper()
     debug_msg 0 "in generate_wrapper()"
 
     case "${machine}:${os}" in
-	x86:Linux|x86_64:Linux|x86:AnyBSD|x86_64:AnyBSD|x86:OpenBSD|x86:QNX)
+	x86:Linux|x86_64:Linux|x86:AnyBSD|x86_64:AnyBSD|x86:OpenBSD|x86_64:OpenBSD|x86:QNX)
 	    wrapper_ibmjava="
 	    IBMJava2-142/jre \\
 	    IBMJava2-141/jre \\
@@ -862,7 +862,7 @@ generate_wrapper()
 
 
 	*:*)
-		error 'os'
+		error os
 	;;
     esac
     wrapper_file="${wrapper_dir}/opera"
@@ -1780,7 +1780,7 @@ xdg()
     fi
 }
 
-echo test | sed -n -e 's/test//' || error 'sed'
+echo test | sed -n -e 's/test//' || error sed
 
 # AnyBSD systems don't have $USERNAME by default
 if test -z "${USERNAME}" && test "${USER}"
